@@ -9,8 +9,11 @@ class MaximumIterationError(Error):
     Exception raised when maximum number of iterations in network reinforcement
     is exceeded.
 
-    Attributes:
-        message -- explanation of the error
+    Attributes
+    -----------
+    message : str
+        Explanation of the error
+
     """
 
     def __init__(self, message):
@@ -21,8 +24,11 @@ class ImpossibleVoltageReduction(Error):
     """
     Exception raised when voltage issue cannot be solved.
 
-    Attributes:
-        message -- explanation of the error
+    Attributes
+    -----------
+    message : str
+        Explanation of the error
+
     """
 
     def __init__(self, message):
