@@ -1,16 +1,17 @@
+import logging
 import math
+
 import networkx as nx
+import numpy as np
+import pandas as pd
+
 from networkx.algorithms.shortest_paths.weighted import (
     _dijkstra as dijkstra_shortest_path_length,
 )
-import pandas as pd
-import numpy as np
 
 from edisgo.network.grids import LVGrid, MVGrid
 
-import logging
-
-logger = logging.getLogger("edisgo")
+logger = logging.getLogger(__name__)
 
 
 def reinforce_mv_lv_station_overloading(edisgo_obj, critical_stations):
@@ -48,13 +49,14 @@ def reinforce_mv_lv_station_overloading(edisgo_obj, critical_stations):
 
     """
     transformers_changes = _station_overloading(
-        edisgo_obj, critical_stations, voltage_level="lv")
+        edisgo_obj, critical_stations, voltage_level="lv"
+    )
 
     if transformers_changes["added"]:
         logger.debug(
             "==> {} LV station(s) has/have been reinforced due to "
-            "overloading issues.".format(
-                str(len(transformers_changes["added"]))))
+            "overloading issues.".format(str(len(transformers_changes["added"])))
+        )
 
     return transformers_changes
 
@@ -94,12 +96,11 @@ def reinforce_hv_mv_station_overloading(edisgo_obj, critical_stations):
 
     """
     transformers_changes = _station_overloading(
-        edisgo_obj, critical_stations, voltage_level="mv")
+        edisgo_obj, critical_stations, voltage_level="mv"
+    )
 
     if transformers_changes["added"]:
-        logger.debug(
-            "==> MV station has been reinforced due to overloading issues."
-        )
+        logger.debug("==> MV station has been reinforced due to overloading issues.")
 
     return transformers_changes
 
@@ -151,8 +152,7 @@ def _station_overloading(edisgo_obj, critical_stations, voltage_level):
                 ]
             ]
         except KeyError:
-            raise KeyError(
-                "Standard MV/LV transformer is not in equipment list.")
+            raise KeyError("Standard MV/LV transformer is not in equipment list.")
     elif voltage_level == "mv":
         try:
             standard_transformer = edisgo_obj.topology.equipment_data[
@@ -163,8 +163,7 @@ def _station_overloading(edisgo_obj, critical_stations, voltage_level):
                 ]
             ]
         except KeyError:
-            raise KeyError(
-                "Standard HV/MV transformer is not in equipment list.")
+            raise KeyError("Standard HV/MV transformer is not in equipment list.")
     else:
         raise ValueError(
             "{} is not a valid option for input variable 'voltage_level' in "
@@ -174,7 +173,10 @@ def _station_overloading(edisgo_obj, critical_stations, voltage_level):
 
     transformers_changes = {"added": {}, "removed": {}}
     for grid_name in critical_stations.index:
-        grid = edisgo_obj.topology._grids[grid_name]
+        if "MV" in grid_name:
+            grid = edisgo_obj.topology.mv_grid
+        else:
+            grid = edisgo_obj.topology.get_lv_grid(grid_name)
         # list of maximum power of each transformer in the station
         s_max_per_trafo = grid.transformers_df.s_nom
         # missing capacity
@@ -188,23 +190,23 @@ def _station_overloading(edisgo_obj, critical_stations, voltage_level):
             # transformer of the same kind as the transformer that best
             # meets the missing power demand
             new_transformers = grid.transformers_df.loc[
-                grid.transformers_df[s_max_per_trafo >= s_trafo_missing][
-                    "s_nom"
-                ].idxmin()
+                [
+                    grid.transformers_df[s_max_per_trafo >= s_trafo_missing][
+                        "s_nom"
+                    ].idxmin()
+                ]
             ]
-            name = new_transformers.name.split("_")
+            name = new_transformers.index[0].split("_")
             name.insert(-1, "reinforced")
             name[-1] = len(grid.transformers_df) + 1
-            new_transformers.name = "_".join([str(_) for _ in name])
+            new_transformers.index = ["_".join([str(_) for _ in name])]
 
             # add new transformer to list of added transformers
-            transformers_changes["added"][grid_name] = [
-                new_transformers.name
-            ]
+            transformers_changes["added"][grid_name] = [new_transformers.index[0]]
         else:
             # get any transformer to get attributes for new transformer from
-            duplicated_transformer = grid.transformers_df.iloc[0]
-            name = duplicated_transformer.name.split("_")
+            duplicated_transformer = grid.transformers_df.iloc[[0]]
+            name = duplicated_transformer.index[0].split("_")
             name.insert(-1, "reinforced")
             duplicated_transformer.s_nom = standard_transformer.S_nom
             duplicated_transformer.type_info = standard_transformer.name
@@ -216,18 +218,24 @@ def _station_overloading(edisgo_obj, critical_stations, voltage_level):
             number_transformers = math.ceil(
                 (s_trafo_missing + s_max_per_trafo.sum()) / standard_transformer.S_nom
             )
-            new_transformers = pd.DataFrame()
+
+            index = []
+
             for i in range(number_transformers):
                 name[-1] = i + 1
-                duplicated_transformer.name = "_".join([str(_) for _ in name])
-                new_transformers = new_transformers.append(
-                    duplicated_transformer
-                )
+                index.append("_".join([str(_) for _ in name]))
+
+            if number_transformers > 1:
+                new_transformers = duplicated_transformer.iloc[
+                    np.arange(len(duplicated_transformer)).repeat(number_transformers)
+                ]
+            else:
+                new_transformers = duplicated_transformer.copy()
+
+            new_transformers.index = index
 
             # add new transformer to list of added transformers
-            transformers_changes["added"][
-                grid_name
-            ] = new_transformers.index.values
+            transformers_changes["added"][grid_name] = new_transformers.index.values
             # add previous transformers to list of removed transformers
             transformers_changes["removed"][
                 grid_name
@@ -244,16 +252,18 @@ def _station_overloading(edisgo_obj, critical_stations, voltage_level):
 
         # add new transformers to topology
         if voltage_level == "lv":
-            edisgo_obj.topology.transformers_df = (
-                edisgo_obj.topology.transformers_df.append(
-                    new_transformers
-                )
+            edisgo_obj.topology.transformers_df = pd.concat(
+                [
+                    edisgo_obj.topology.transformers_df,
+                    new_transformers,
+                ]
             )
         else:
-            edisgo_obj.topology.transformers_hvmv_df = (
-                edisgo_obj.topology.transformers_hvmv_df.append(
-                    new_transformers
-                )
+            edisgo_obj.topology.transformers_hvmv_df = pd.concat(
+                [
+                    edisgo_obj.topology.transformers_hvmv_df,
+                    new_transformers,
+                ]
             )
     return transformers_changes
 
@@ -295,41 +305,41 @@ def reinforce_mv_lv_station_voltage_issues(edisgo_obj, critical_stations):
         standard_transformer = edisgo_obj.topology.equipment_data[
             "lv_transformers"
         ].loc[
-            edisgo_obj.config["grid_expansion_standard_equipment"][
-                "mv_lv_transformer"
-            ]
+            edisgo_obj.config["grid_expansion_standard_equipment"]["mv_lv_transformer"]
         ]
     except KeyError:
         raise KeyError("Standard MV/LV transformer is not in equipment list.")
 
     transformers_changes = {"added": {}}
-    for grid_repr in critical_stations.keys():
-        grid = edisgo_obj.topology._grids[grid_repr]
+    for grid_name in critical_stations.keys():
+        if "MV" in grid_name:
+            grid = edisgo_obj.topology.mv_grid
+        else:
+            grid = edisgo_obj.topology.get_lv_grid(grid_name)
         # get any transformer to get attributes for new transformer from
-        duplicated_transformer = grid.transformers_df.iloc[0]
+        duplicated_transformer = grid.transformers_df.iloc[[0]]
         # change transformer parameters
-        name = duplicated_transformer.name.split("_")
+        name = duplicated_transformer.index[0].split("_")
         name.insert(-1, "reinforced")
         name[-1] = len(grid.transformers_df) + 1
-        duplicated_transformer.name = "_".join([str(_) for _ in name])
+        duplicated_transformer.index = ["_".join([str(_) for _ in name])]
         duplicated_transformer.s_nom = standard_transformer.S_nom
         duplicated_transformer.r_pu = standard_transformer.r_pu
         duplicated_transformer.x_pu = standard_transformer.x_pu
         duplicated_transformer.type_info = standard_transformer.name
         # add new transformer to topology
-        edisgo_obj.topology.transformers_df = edisgo_obj.topology.transformers_df.append(
-            duplicated_transformer
+        edisgo_obj.topology.transformers_df = pd.concat(
+            [
+                edisgo_obj.topology.transformers_df,
+                duplicated_transformer,
+            ]
         )
-        transformers_changes["added"][grid_repr] = [
-            duplicated_transformer.name
-        ]
+        transformers_changes["added"][grid_name] = duplicated_transformer.index.tolist()
 
     if transformers_changes["added"]:
         logger.debug(
             "==> {} LV station(s) has/have been reinforced due to voltage "
-            "issues.".format(
-                len(transformers_changes["added"])
-            )
+            "issues.".format(len(transformers_changes["added"]))
         )
 
     return transformers_changes
@@ -383,11 +393,13 @@ def reinforce_lines_voltage_issues(edisgo_obj, grid, crit_nodes):
 
     # load standard line data
     if isinstance(grid, LVGrid):
-        standard_line = edisgo_obj.config[
-            "grid_expansion_standard_equipment"]["lv_line"]
+        standard_line = edisgo_obj.config["grid_expansion_standard_equipment"][
+            "lv_line"
+        ]
     elif isinstance(grid, MVGrid):
-        standard_line = edisgo_obj.config[
-            "grid_expansion_standard_equipment"]["mv_line"]
+        standard_line = edisgo_obj.config["grid_expansion_standard_equipment"][
+            f"mv_line_{int(grid.nominal_voltage)}kv"
+        ]
     else:
         raise ValueError("Inserted grid is invalid.")
 
@@ -414,7 +426,7 @@ def reinforce_lines_voltage_issues(edisgo_obj, grid, crit_nodes):
     for repr_node in nodes_feeder.keys():
 
         # find node farthest away
-        get_weight = lambda u, v, data: data["length"]
+        get_weight = lambda u, v, data: data["length"]  # noqa: E731
         path_length = 0
         for n in nodes_feeder[repr_node]:
             path_length_dict_tmp = dijkstra_shortest_path_length(
@@ -429,9 +441,7 @@ def reinforce_lines_voltage_issues(edisgo_obj, grid, crit_nodes):
         # find first node in path that exceeds 2/3 of the line length
         # from station to critical node farthest away from the station
         node_2_3 = next(
-            j
-            for j in path
-            if path_length_dict[j] >= path_length_dict[node] * 2 / 3
+            j for j in path if path_length_dict[j] >= path_length_dict[node] * 2 / 3
         )
 
         # if LVGrid: check if node_2_3 is outside of a house
@@ -450,10 +460,7 @@ def reinforce_lines_voltage_issues(edisgo_obj, grid, crit_nodes):
         # if MVGrid: check if node_2_3 is LV station and if not find
         # next LV station
         else:
-            while (
-                node_2_3
-                not in edisgo_obj.topology.transformers_df.bus0.values
-            ):
+            while node_2_3 not in edisgo_obj.topology.transformers_df.bus0.values:
                 try:
                     # try to find LVStation behind node_2_3
                     node_2_3 = path[path.index(node_2_3) + 1]
@@ -468,19 +475,22 @@ def reinforce_lines_voltage_issues(edisgo_obj, grid, crit_nodes):
         # directly connected to the station), line cannot be
         # disconnected and must therefore be reinforced
         if node_2_3 in nodes_feeder.keys():
-            crit_line_name = graph.get_edge_data(
-                station_node, node_2_3
-            )["branch_name"]
+            crit_line_name = graph.get_edge_data(station_node, node_2_3)["branch_name"]
             crit_line = grid.lines_df.loc[crit_line_name]
 
             # if critical line is already a standard line install one
             # more parallel line
             if crit_line.type_info == standard_line:
                 edisgo_obj.topology.update_number_of_parallel_lines(
-                    pd.Series(index=[crit_line_name],
-                              data=[edisgo_obj.topology._lines_df.at[
-                                        crit_line_name, "num_parallel"] + 1]
-                              )
+                    pd.Series(
+                        index=[crit_line_name],
+                        data=[
+                            edisgo_obj.topology._lines_df.at[
+                                crit_line_name, "num_parallel"
+                            ]
+                            + 1
+                        ],
+                    )
                 )
                 lines_changes[crit_line_name] = 1
 
@@ -490,8 +500,7 @@ def reinforce_lines_voltage_issues(edisgo_obj, grid, crit_nodes):
                 # number of parallel standard lines could be calculated
                 # following [2] p.103; for now number of parallel
                 # standard lines is iterated
-                edisgo_obj.topology.change_line_type([crit_line_name],
-                                                     standard_line)
+                edisgo_obj.topology.change_line_type([crit_line_name], standard_line)
                 lines_changes[crit_line_name] = 1
 
         # if node_2_3 is not a representative, disconnect line
@@ -499,36 +508,25 @@ def reinforce_lines_voltage_issues(edisgo_obj, grid, crit_nodes):
             # get line between node_2_3 and predecessor node (that is
             # closer to the station)
             pred_node = path[path.index(node_2_3) - 1]
-            crit_line_name = graph.get_edge_data(node_2_3, pred_node)[
-                "branch_name"
-            ]
+            crit_line_name = graph.get_edge_data(node_2_3, pred_node)["branch_name"]
             if grid.lines_df.at[crit_line_name, "bus0"] == pred_node:
-                edisgo_obj.topology._lines_df.at[
-                    crit_line_name, "bus0"
-                ] = station_node
+                edisgo_obj.topology._lines_df.at[crit_line_name, "bus0"] = station_node
             elif grid.lines_df.at[crit_line_name, "bus1"] == pred_node:
-                edisgo_obj.topology._lines_df.at[
-                    crit_line_name, "bus1"
-                ] = station_node
+                edisgo_obj.topology._lines_df.at[crit_line_name, "bus1"] = station_node
             else:
-                raise ValueError(
-                    "Bus not in line buses. " "Please check."
-                )
+                raise ValueError("Bus not in line buses. Please check.")
             # change line length and type
             edisgo_obj.topology._lines_df.at[
                 crit_line_name, "length"
             ] = path_length_dict[node_2_3]
-            edisgo_obj.topology.change_line_type(
-                [crit_line_name],
-                standard_line)
+            edisgo_obj.topology.change_line_type([crit_line_name], standard_line)
             lines_changes[crit_line_name] = 1
+            # ToDo: Include switch disconnector
 
     if not lines_changes:
         logger.debug(
             "==> {} line(s) was/were reinforced due to voltage "
-            "issues.".format(
-                len(lines_changes)
-            )
+            "issues.".format(len(lines_changes))
         )
 
     return lines_changes
@@ -537,7 +535,7 @@ def reinforce_lines_voltage_issues(edisgo_obj, grid, crit_nodes):
 def reinforce_lines_overloading(edisgo_obj, crit_lines):
     """
     Reinforce lines in MV and LV topology due to overloading.
-    
+
     Parameters
     ----------
     edisgo_obj : :class:`~.EDisGo`
@@ -557,7 +555,7 @@ def reinforce_lines_overloading(edisgo_obj, crit_lines):
     dict
         Dictionary with name of lines as keys and the corresponding number of
         lines added as values.
-        
+
     Notes
     -----
     Reinforce measures:
@@ -572,28 +570,24 @@ def reinforce_lines_overloading(edisgo_obj, crit_lines):
 
     lines_changes = {}
     # reinforce mv lines
-    lines_changes.update(_reinforce_lines_overloading_per_grid_level(
-        edisgo_obj, "mv", crit_lines
-    ))
+    lines_changes.update(
+        _reinforce_lines_overloading_per_grid_level(edisgo_obj, "mv", crit_lines)
+    )
     # reinforce lv lines
-    lines_changes.update(_reinforce_lines_overloading_per_grid_level(
-        edisgo_obj, "lv", crit_lines
-    ))
+    lines_changes.update(
+        _reinforce_lines_overloading_per_grid_level(edisgo_obj, "lv", crit_lines)
+    )
 
     if not crit_lines.empty:
         logger.debug(
             "==> {} line(s) was/were reinforced due to over-loading "
-            "issues.".format(
-                crit_lines.shape[0]
-            )
+            "issues.".format(crit_lines.shape[0])
         )
 
     return lines_changes
 
 
-def _reinforce_lines_overloading_per_grid_level(
-    edisgo_obj, voltage_level, crit_lines
-):
+def _reinforce_lines_overloading_per_grid_level(edisgo_obj, voltage_level, crit_lines):
     """
     Reinforce lines in MV or LV topology due to overloading.
 
@@ -621,6 +615,7 @@ def _reinforce_lines_overloading_per_grid_level(
         lines added as values.
 
     """
+
     def _add_parallel_standard_lines(lines):
         """
         Adds as many parallel standard lines as needed so solve overloading.
@@ -635,8 +630,8 @@ def _reinforce_lines_overloading_per_grid_level(
         """
         # calculate necessary number of parallel lines
         number_parallel_lines = np.ceil(
-            crit_lines.max_rel_overload[lines] *
-            edisgo_obj.topology.lines_df.loc[lines, "num_parallel"]
+            crit_lines.max_rel_overload[lines]
+            * edisgo_obj.topology.lines_df.loc[lines, "num_parallel"]
         )
 
         # add number of added lines to lines_changes
@@ -648,8 +643,7 @@ def _reinforce_lines_overloading_per_grid_level(
         )
 
         # update number of parallel lines and line accordingly attributes
-        edisgo_obj.topology.update_number_of_parallel_lines(
-            number_parallel_lines)
+        edisgo_obj.topology.update_number_of_parallel_lines(number_parallel_lines)
 
     def _add_one_parallel_line_of_same_type(lines):
         """
@@ -664,15 +658,12 @@ def _reinforce_lines_overloading_per_grid_level(
 
         """
         # add number of added lines to lines_changes
-        lines_changes.update(
-            pd.Series(index=lines,
-                      data=[1] * len(lines)).to_dict()
-        )
+        lines_changes.update(pd.Series(index=lines, data=[1] * len(lines)).to_dict())
 
         # update number of lines and accordingly line attributes
         edisgo_obj.topology.update_number_of_parallel_lines(
-            pd.Series(index=lines,
-                      data=[2] * len(lines)))
+            pd.Series(index=lines, data=[2] * len(lines))
+        )
 
     def _replace_by_parallel_standard_lines(lines):
         """
@@ -690,59 +681,64 @@ def _reinforce_lines_overloading_per_grid_level(
         s_nom_old = edisgo_obj.topology.lines_df.loc[lines, "s_nom"]
 
         # change line type to standard line
-        edisgo_obj.topology.change_line_type(
-            lines,
-            standard_line_type)
+        edisgo_obj.topology.change_line_type(lines, standard_line_type)
 
         # calculate and update number of parallel lines
         number_parallel_lines = np.ceil(
-            s_nom_old * crit_lines.loc[lines, "max_rel_overload"]
+            s_nom_old
+            * crit_lines.loc[lines, "max_rel_overload"]
             / edisgo_obj.topology.lines_df.loc[lines, "s_nom"]
         )
-        edisgo_obj.topology.update_number_of_parallel_lines(
-            number_parallel_lines)
+        edisgo_obj.topology.update_number_of_parallel_lines(number_parallel_lines)
 
         lines_changes.update(number_parallel_lines.to_dict())
 
-    standard_line_type = \
-        edisgo_obj.config["grid_expansion_standard_equipment"][
-            "{}_line".format(voltage_level)
-        ]
-
     lines_changes = {}
 
     # chose lines of right grid level
     relevant_lines = edisgo_obj.topology.lines_df.loc[
         crit_lines[crit_lines.voltage_level == voltage_level].index
     ]
-
-    # handling of standard lines
-    lines_standard = relevant_lines.loc[
-        relevant_lines.type_info == standard_line_type
+    if not relevant_lines.empty:
+        nominal_voltage = edisgo_obj.topology.buses_df.loc[
+            edisgo_obj.topology.lines_df.loc[relevant_lines.index[0], "bus0"], "v_nom"
         ]
-    if not lines_standard.empty:
-        _add_parallel_standard_lines(lines_standard.index)
+        if nominal_voltage == 0.4:
+            standard_line_type = edisgo_obj.config["grid_expansion_standard_equipment"][
+                "lv_line"
+            ]
+        else:
+            standard_line_type = edisgo_obj.config["grid_expansion_standard_equipment"][
+                f"mv_line_{int(nominal_voltage)}kv"
+            ]
 
-    # get lines that have not been updated yet (i.e. that are not standard
-    # lines)
-    relevant_lines = relevant_lines.loc[
-        ~relevant_lines.index.isin(lines_standard.index)
-    ]
-    # handling of cables where adding one cable is sufficient
-    lines_single = (
-        relevant_lines.loc[relevant_lines.num_parallel == 1]
+        # handling of standard lines
+        lines_standard = relevant_lines.loc[
+            relevant_lines.type_info == standard_line_type
+        ]
+        if not lines_standard.empty:
+            _add_parallel_standard_lines(lines_standard.index)
+
+        # get lines that have not been updated yet (i.e. that are not standard
+        # lines)
+        relevant_lines = relevant_lines.loc[
+            ~relevant_lines.index.isin(lines_standard.index)
+        ]
+        # handling of cables where adding one cable is sufficient
+        lines_single = (
+            relevant_lines.loc[relevant_lines.num_parallel == 1]
             .loc[relevant_lines.kind == "cable"]
             .loc[crit_lines.max_rel_overload < 2]
-    )
-    if not lines_single.empty:
-        _add_one_parallel_line_of_same_type(lines_single.index)
+        )
+        if not lines_single.empty:
+            _add_one_parallel_line_of_same_type(lines_single.index)
 
-    # handle rest of lines (replace by as many parallel standard lines as
-    # needed)
-    relevant_lines = relevant_lines.loc[
-        ~relevant_lines.index.isin(lines_single.index)
-    ]
-    if not relevant_lines.empty:
-        _replace_by_parallel_standard_lines(relevant_lines.index)
+        # handle rest of lines (replace by as many parallel standard lines as
+        # needed)
+        relevant_lines = relevant_lines.loc[
+            ~relevant_lines.index.isin(lines_single.index)
+        ]
+        if not relevant_lines.empty:
+            _replace_by_parallel_standard_lines(relevant_lines.index)
 
     return lines_changes
